@@ -29,6 +29,9 @@ FAILEDOPERATION_ADDRESSENIINFONOTFOUND = 'FailedOperation.AddressEniInfoNotFound
 # 账户余额不足。
 FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'
 
+# 创建云联网失败. 请重试你的请求，如果问题仍然存在，请联系腾讯云客服。
+FAILEDOPERATION_CREATECCNFAILED = 'FailedOperation.CreateCcnFailed'
+
 # 不支持的地域。
 FAILEDOPERATION_INVALIDREGION = 'FailedOperation.InvalidRegion'
 
@@ -341,6 +344,9 @@ INVALIDPARAMETERVALUE_NETDETECTSAMEIP = 'InvalidParameterValue.NetDetectSameIp'
 # 网络接口ID不正确。
 INVALIDPARAMETERVALUE_NETWORKINTERFACEIDMALFORMED = 'InvalidParameterValue.NetworkInterfaceIdMalformed'
 
+# 网卡所绑定实例不支持绑定弹性公网IPv6
+INVALIDPARAMETERVALUE_NETWORKINTERFACEINSTANCENOTSUPPORT = 'InvalidParameterValue.NetworkInterfaceInstanceNotSupport'
+
 # 未找到网络接口ID，或私有IP地址未在网络接口配置。
 INVALIDPARAMETERVALUE_NETWORKINTERFACENOTFOUND = 'InvalidParameterValue.NetworkInterfaceNotFound'
 
@@ -605,6 +611,9 @@ LIMITEXCEEDED_PUBLICIPADDRESSPERNATGATEWAYLIMITEXCEEDED = 'LimitExceeded.PublicI
 # 安全组规则数量超过上限。
 LIMITEXCEEDED_SECURITYGROUPPOLICYSET = 'LimitExceeded.SecurityGroupPolicySet'
 
+# SSL-VPN客户端个数大于SSL-VPN-SERVER客户端地址池能够分配的个数。
+LIMITEXCEEDED_SSLVPNCLIENTLIMITEXCEEDED = 'LimitExceeded.SslVpnClientLimitExceeded'
+
 # 子网分配子网段数量达到上限。
 LIMITEXCEEDED_SUBNETCIDRBLOCK = 'LimitExceeded.SubnetCidrBlock'
 
@@ -773,6 +782,9 @@ UNSUPPORTEDOPERATION_CCNHASFLOWLOG = 'UnsupportedOperation.CcnHasFlowLog'
 # CCN实例所属账号未通过联通审批。
 UNSUPPORTEDOPERATION_CCNINSTANCEACCOUNTNOTAPPROVEDBYUNICOM = 'UnsupportedOperation.CcnInstanceAccountNotApprovedByUnicom'
 
+# 云联网开启ipv6不支持创建多路由表
+UNSUPPORTEDOPERATION_CCNIPV6NOTSUPPORTMULTIPLEROUTETABLE = 'UnsupportedOperation.CcnIpv6NotSupportMultipleRouteTable'
+
 # 实例未关联CCN。
 UNSUPPORTEDOPERATION_CCNNOTATTACHED = 'UnsupportedOperation.CcnNotAttached'
 
@@ -803,6 +815,12 @@ UNSUPPORTEDOPERATION_CLBPOLICYLIMIT = 'UnsupportedOperation.ClbPolicyLimit'
 # 与该VPC下的TKE容器的网段重叠。
 UNSUPPORTEDOPERATION_CONFLICTWITHDOCKERROUTE = 'UnsupportedOperation.ConflictWithDockerRoute'
 
+# 当前账号不允许创建服务质量：铜云联网。
+UNSUPPORTEDOPERATION_COPPERCCNNOTSUPPORTEDCREATE = 'UnsupportedOperation.CopperCcnNotSupportedCreate'
+
+# 服务质量：铜云联网仅支持创建预付费模式。
+UNSUPPORTEDOPERATION_COPPERCCNSUPPORTEDPREPAID = 'UnsupportedOperation.CopperCcnSupportedPrepaid'
+
 # 当前账号非联通账号。
 UNSUPPORTEDOPERATION_CURRENTACCOUNTISNOTUNICOMACCOUNT = 'UnsupportedOperation.CurrentAccountIsNotUnicomAccount'
 
@@ -1016,6 +1034,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTZONE = 'UnsupportedOperation.NotSupportZone'
 # 该地址类型不支持释放操作。
 UNSUPPORTEDOPERATION_NOTSUPPORTEDADDRESSIPSCHARGETYPE = 'UnsupportedOperation.NotSupportedAddressIpsChargeType'
 
+# 不支持创建后付费流量计费类型云联网
+UNSUPPORTEDOPERATION_NOTSUPPORTEDCREATETRAFFICMETERINGTYPECCN = 'UnsupportedOperation.NotSupportedCreateTrafficMeteringTypeCcn'
+
 # 此地域没有上线出口二资源，请到北京/广州/南京购买。
 UNSUPPORTEDOPERATION_NOTSUPPORTEDPURCHASECENTEREGRESSRESOURCE = 'UnsupportedOperation.NotSupportedPurchaseCenterEgressResource'
 
@@ -1031,6 +1052,9 @@ UNSUPPORTEDOPERATION_OFFLINECHARGETYPE = 'UnsupportedOperation.OfflineChargeType
 # 仅支持专业版Ckafka。
 UNSUPPORTEDOPERATION_ONLYSUPPORTPROFESSIONKAFKA = 'UnsupportedOperation.OnlySupportProfessionKafka'
 
+# 预付费云联网只支持带宽计量类型
+UNSUPPORTEDOPERATION_PREPAIDCCNONLYSUPPORTBANDWIDTHMETERING = 'UnsupportedOperation.PrepaidCcnOnlySupportBandwidthMetering'
+
 # 预付费云联网只支持地域间限速。
 UNSUPPORTEDOPERATION_PREPAIDCCNONLYSUPPORTINTERREGIONLIMIT = 'UnsupportedOperation.PrepaidCcnOnlySupportInterRegionLimit'
 
@@ -1061,6 +1085,9 @@ UNSUPPORTEDOPERATION_RECORDEXISTS = 'UnsupportedOperation.RecordExists'
 # 记录不存在。
 UNSUPPORTEDOPERATION_RECORDNOTEXISTS = 'UnsupportedOperation.RecordNotExists'
 
+# 此安全组存在嵌套安全组规则，不支持跨地域克隆。
+UNSUPPORTEDOPERATION_REMOTEREGIONSGHASREFERENCEDSG = 'UnsupportedOperation.RemoteRegionSgHasReferencedSg'
+
 # 资源处于不可用状态，禁止操作。
 UNSUPPORTEDOPERATION_RESOURCEISINVALIDSTATE = 'UnsupportedOperation.ResourceIsInvalidState'
 
